import check
from grids import *

class ThreeD:
    """
    Fields: entries (listof Grid), dim_one (Int), dim_two (Int), dim_three (Int)
    Requires: 0 < dim_one
              0 < dim_two
              0 < dim_three
    """

    ## ThreeD(a, b, c) produces a ThreeD object with dimensions a x b x c
    ## __init__: Int Int Int -> ThreeD
    ## Requires: 0 < a
    ##           0 < b
    ##           0 < c
    def __init__(self, a, b, c):
        self.entries = []
        self.dim_one = a
        self.dim_two = b
        self.dim_three = c
        for dim in range(a):
            new_entry = Grid(b, c)
            self.entries.append(new_entry)

    ## repr(self) produces a string with all entries
    ## __repr__: ThreeD -> Str
    def __repr__(self):
        output = "["
        for grid in range(self.dim_one):
            output = output + repr(self.entries[grid]) + ", \n"
        return output + "]"

    ## self = other produces True if self and other contain the same values
    ## __eq__: ThreeD ThreeD -> Bool
    def __eq__(self, other):
        if self.dim_one != other.dim_one or self.dim_two != other.dim_two \
           or self.dim_three != other.dim_three:
            return False
        for grid in range(self.dim_one):
            if self.entries[grid] != other.entries[grid]:
                return False
        return True

    ## self.access(i, j, k) returns the entry in i, j, k
    ## access: ThreeD Int Int Int -> Any
    ## Requires: 0 <= i < self.dim_one
    ##           0 <= j < self.dim_two
    ##           0 <= k < self.dim_three
    def access(self, i, j, k):
        return self.entries[i].access(j, k)

    ## self.enter(i, j, k, item) enters item in i, j, k
    ## Effects: Mutates self
    ## enter: ThreeD Int Int Int Any -> None
    ## Requires: 0 <= i < self.dim_one
    ##           0 <= j < self.dim_two
    ##           0 <= k < self.dim_three
    def enter(self, i, j, k, item):
        self.entries[i].enter(j, k, item)


